==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/init_files_tests/redefined_need.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'redefined_need'} = {
  'contents' => [
    {
      'contents' => [
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => '0.1'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'need',
          'extra' => {
            'misc_args' => [
              '0.1'
            ],
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 1,
            'macro' => ''
          }
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'redefined_need'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'redefined_need'}{'contents'}[0]{'contents'}[0]{'args'}[0];
$result_trees{'redefined_need'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'redefined_need'}{'contents'}[0]{'contents'}[0];
$result_trees{'redefined_need'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'redefined_need'}{'contents'}[0];
$result_trees{'redefined_need'}{'contents'}[0]{'parent'} = $result_trees{'redefined_need'};

$result_texis{'redefined_need'} = '@need 0.1
';


$result_texts{'redefined_need'} = '';

$result_errors{'redefined_need'} = [];


$result_floats{'redefined_need'} = {};



$result_converted{'html'}->{'redefined_need'} = '<!DOCTYPE html>
<html>
<!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<title>Untitled Document</title>

<meta name="description" content="Untitled Document">
<meta name="keywords" content="Untitled Document">
<meta name="resource-type" content="document">
<meta name="distribution" content="global">
<meta name="viewport" content="width=device-width,initial-scale=1">



</head>

<body lang="en">
<!-- need: 0.1 -->



</body>
</html>
';

$result_converted_errors{'html'}->{'redefined_need'} = [
  {
    'error_line' => 'warning: must specify a title with a title command or @top
',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: need has the right arg: 0.1
',
    'file_name' => '',
    'line_nr' => 1,
    'macro' => '',
    'text' => 'need has the right arg: 0.1',
    'type' => 'warning'
  }
];


1;

==> texinfo-7.1.1.tar.xz: texinfo-7.1.1/tp/t/results/init_files_tests/redefined_need.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'redefined_need'} = {
  'contents' => [
    {
      'contents' => [
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => '0.1'
                }
              ],
              'info' => {
                'spaces_after_argument' => {
                  'text' => '
'
                }
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'need',
          'extra' => {
            'misc_args' => [
              '0.1'
            ]
          },
          'info' => {
            'spaces_before_argument' => {
              'text' => ' '
            }
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 1,
            'macro' => ''
          }
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'redefined_need'} = '@need 0.1
';


$result_texts{'redefined_need'} = '';

$result_errors{'redefined_need'} = [];


$result_floats{'redefined_need'} = {};



$result_converted{'html'}->{'redefined_need'} = '<!DOCTYPE html>
<html>
<!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<title>Untitled Document</title>

<meta name="description" content="Untitled Document">
<meta name="keywords" content="Untitled Document">
<meta name="resource-type" content="document">
<meta name="distribution" content="global">
<meta name="viewport" content="width=device-width,initial-scale=1">



</head>

<body lang="en">
<!-- need: 0.1 -->



</body>
</html>
';

$result_converted_errors{'html'}->{'redefined_need'} = [
  {
    'error_line' => 'warning: must specify a title with a title command or @top
',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: need has the right arg: 0.1
',
    'file_name' => '',
    'line_nr' => 1,
    'macro' => '',
    'text' => 'need has the right arg: 0.1',
    'type' => 'warning'
  }
];


1;
